module.exports = {
    Clr: 0,
    Go: 1,
    Jvm: 2,
    Netcore: 3,
    Perl: 4,
    Python: 5,
    Ruby: 6,
    Nodejs: 7,
    Cpp: 8
}